summaryrefslogtreecommitdiffstats
path: root/kmail/imapaccountbase.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kmail/imapaccountbase.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/imapaccountbase.h')
-rw-r--r--kmail/imapaccountbase.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kmail/imapaccountbase.h b/kmail/imapaccountbase.h
index c533171d..533be483 100644
--- a/kmail/imapaccountbase.h
+++ b/kmail/imapaccountbase.h
@@ -60,7 +60,7 @@ namespace KMail {
Q_OBJECT
TQ_OBJECT
protected:
- ImapAccountBase( AccountManager * tqparent, const TQString & name, uint id );
+ ImapAccountBase( AccountManager * parent, const TQString & name, uint id );
public:
virtual ~ImapAccountBase();
@@ -142,13 +142,13 @@ namespace KMail {
struct jobData
{
// Needed by TQMap, don't use
- jobData() : url(TQString()), tqparent(0), current(0), total(1), done(0), offset(0), progressItem(0),
+ jobData() : url(TQString()), parent(0), current(0), total(1), done(0), offset(0), progressItem(0),
onlySubscribed(false), quiet(false), cancellable(false) {}
// Real constructor
- jobData( const TQString& _url, KMFolder *_tqparent = 0,
+ jobData( const TQString& _url, KMFolder *_parent = 0,
int _total = 1, int _done = 0, bool _quiet = false,
bool _cancelable = false )
- : url(_url), tqparent(_tqparent), current(0), total(_total), done(_done), offset(0),
+ : url(_url), parent(_parent), current(0), total(_total), done(_done), offset(0),
progressItem(0), quiet(_quiet), cancellable(_cancelable) {}
TQString path;
@@ -157,7 +157,7 @@ namespace KMail {
TQByteArray data;
TQCString cdata;
TQStringList items;
- KMFolder *tqparent, *current;
+ KMFolder *parent, *current;
TQPtrList<KMMessage> msgList;
int total, done, offset;
KPIM::ProgressItem *progressItem;
@@ -401,16 +401,16 @@ namespace KMail {
return mCapabilities.contains( capa ); }
/**
* Create an IMAP path for a tqparent folder and a foldername
* Parent and folder are separated with the delimiter of the account
* The path starts and ends with '/'
*/
- TQString createImapPath( FolderStorage* tqparent, const TQString& folderName );
+ TQString createImapPath( FolderStorage* parent, const TQString& folderName );
/**
* Create an IMAP path for a tqparent imapPath and a folderName
*/
- TQString createImapPath( const TQString& tqparent, const TQString& folderName );
+ TQString createImapPath( const TQString& parent, const TQString& folderName );
public slots:
@@ -511,7 +511,7 @@ namespace KMail {
* Build KMMessageParts and DwBodyParts from the bodystructure-stream
*/
void constructParts( TQDataStream & stream, int count, KMMessagePart* parentKMPart,
- DwBodyPart * tqparent, const DwMessage * dwmsg );
+ DwBodyPart * parent, const DwMessage * dwmsg );
/** Migrate the prefix */
void migratePrefix();
@@ -401,16 +401,16 @@ namespace KMail {
return mCapabilities.contains( capa ); }
/**
- * Create an IMAP path for a tqparent folder and a foldername
+ * Create an IMAP path for a parent folder and a foldername
* Parent and folder are separated with the delimiter of the account
* The path starts and ends with '/'
@@ -401,16 +401,16 @@ namespace KMail {
/**
- * Create an IMAP path for a tqparent imapPath and a folderName
+ * Create an IMAP path for a parent imapPath and a folderName
*/